import { api } from '@nice/client';
import { Pagination } from 'antd';
import React, { useState } from 'react';

// 定义 TrainSituation 接口
interface TrainSituation {
    id: string;
    staffId: string;
    score: number;
}

// 定义 Staff 接口
interface Staff {
    id: string;
    username: string;
    absent: boolean;
    // trainSituations: TrainSituation[];
}

interface PaginatedResponse {
    items: Staff[];
    total: number;
}

const TestPage: React.FC = () => {
    const [currentPage, setCurrentPage] = useState(1);
    const pageSize = 10;

    // 使用 findManyWithPagination 替换原来的两个查询
    const { data, isLoading } = api.staff.findManyWithPagination.useQuery<PaginatedResponse>({
        page: currentPage,
        pageSize: pageSize,
        where: { deletedAt: null },
        select: {
            id: true,
            username: true,
            absent: true,
        }
    });
    console.log(data);

    // data 中包含了分页数据和总记录数
    const staffs = (data?.items || []) as Staff[];
    const totalCount = data?.total || 0;

    // 分页处理函数
    const handlePageChange = (page: number) => {
        setCurrentPage(page);
    };

    return (
        <div className="p-6">
            <h1 className="text-2xl font-bold mb-4 text-center">培训情况记录</h1>
            <div className="overflow-x-auto">
                <table className="min-w-full bg-white shadow-md rounded-lg">
                    <thead>
                        <tr className="bg-gray-100 border-b">
                            <th className="px-6 py-3 text-center text-xs font-medium text-gray-600 uppercase tracking-wider">培训记录ID</th>
                            <th className="px-6 py-3 text-center text-xs font-medium text-gray-600 uppercase tracking-wider">员工ID</th>
                            <th className="px-6 py-3 text-center text-xs font-medium text-gray-600 uppercase tracking-wider">在位</th>
                        </tr>
                    </thead>
                    <tbody className="divide-y divide-gray-200">
                        {staffs.map((staff) => (
                            <tr key={staff.id} className="hover:bg-gray-50">
                                <td className="px-6 py-4 whitespace-nowrap text-center">
                                    {staff.id}
                                </td>
                                <td className="px-6 py-4 whitespace-nowrap text-center">
                                    {staff.username}
                                </td>
                                <td className="px-6 py-4 whitespace-nowrap text-center">
                                    {staff.absent ? '在位' : '不在位'}
                                </td>
                            </tr>
                        ))}
                    </tbody>
                </table>
            </div>

            <div className="mt-4 flex justify-center">
                <Pagination
                    current={currentPage}
                    total={totalCount}
                    pageSize={pageSize}
                    onChange={handlePageChange}
                    showTotal={(total) => `共 ${total} 条记录`}
                    showSizeChanger={false}
                    showQuickJumper
                />
            </div>
        </div>
    );
};

export default TestPage;